#include "FilelistItem.h"
#include <File.h>
#include <Path.h>
#include <Font.h>
#include <Node.h>
#include <NodeInfo.h>
#include <Bitmap.h>
#include <Mime.h>
#include <ListItem.h>

CFilelistItem::CFilelistItem( entry_ref *ref )
	: BListItem(), _ref(*ref)
{
}

//--------------------------------------------------------------------

void CFilelistItem::Update( BView *owner, const BFont *finfo )
{
	BListItem::Update( owner, finfo );
	if( Height() < 17 )
		SetHeight( 17 );
}

//--------------------------------------------------------------------

void CFilelistItem::DrawItem( BView *owner, BRect r, bool complete )
{
	BBitmap		*bitmap;
	BEntry		entry;
	BFile		file;
	BFont		font = *be_plain_font;
	BNodeInfo	*info;
	BPath		path;
	BRect		sr;
	BRect		dr;

	if ( IsSelected() ) 
	{
		owner->SetHighColor( 180, 180, 180 );
		owner->SetLowColor( 180, 180, 180 );
	}
	else 
	{
		owner->SetHighColor( 255, 255, 255 );
		owner->SetLowColor( 255, 255, 255 );
	}
	owner->FillRect( r );
	owner->SetHighColor( 0, 0, 0 );

	font.SetSize( FONT_SIZE );
	owner->SetFont( &font );
	owner->MovePenTo( r.left + 24, r.bottom - 4 );

	entry.SetTo( &_ref );
	if ( entry.GetPath( &path ) == B_NO_ERROR )
		owner->DrawString( path.Path() );
	else
		owner->DrawString( "<missing enclosure>" );

	file.SetTo( &_ref, O_RDONLY );
	if ( file.InitCheck() == B_NO_ERROR ) 
	{
		info = new BNodeInfo( &file );
		sr.Set( 0, 0, B_MINI_ICON - 1, B_MINI_ICON - 1 );
		bitmap = new BBitmap( sr, B_COLOR_8_BIT );
		if ( info->GetTrackerIcon( bitmap, B_MINI_ICON ) == B_NO_ERROR ) 
		{
			dr.Set( r.left + 4, r.top + 1, r.left + 4 + 15, r.top + 1 + 15 );
			owner->SetDrawingMode( B_OP_OVER );
			owner->DrawBitmap( bitmap, sr, dr );
			owner->SetDrawingMode( B_OP_COPY );
		}
		delete bitmap;
		delete info;
	}
}

//--------------------------------------------------------------------

bool CFilelistItem::operator==(const CFilelistItem &item ) const
{
	return _ref == item._ref;
}

//--------------------------------------------------------------------


entry_ref* CFilelistItem::Ref()
{
	return &_ref;
}
